``DustPy`` Documentation
=========================================

| ``DustPy`` is a dust coagulation and evolution code for protoplanetary disks.

| This documentation is for ``DustPy v0.5.8``.

| To install ``DustPy`` simply type
| ``pip install dustpy``

| ``DustPy`` is based on the ``simframe`` framework for scientific simulation.
| Please have a look at the `Simframe Documentation <https://simframe.rtfd.io>`_ for details of its usage.

| The following examples demonstrate the usage of ``DustPy``.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   1_basics
   2_simple_customization
   3_advanced_customization
   4_standard_model
   5_dust_coagulation
   6_dust_evolution
   7_gas_evolution
   test_analytical_coagulation_kernels
   test_gas_evolution
   example_ice_lines
   example_planetary_gaps
   example_planetesimal_formation
   A_publications
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
